package baselinecomparison;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Date;

import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.border.TitledBorder;

import com.wily.introscope.console.thornhill.manager.IThornhillItem;
import com.wily.introscope.console.thornhill.manager.agent.ThornhillAgent;
import com.wily.introscope.console.thornhill.manager.agent.ThornhillMetric;
import com.wily.introscope.console.thornhill.manager.agent.ThornhillMetricPath;
import com.wily.introscope.console.thornhill.manager.clock.ClockManager;
import com.wily.introscope.console.thornhill.ui.ThornhillUserInterface;
import com.wily.introscope.spec.metric.AgentName;
import com.wily.ui.IGenericServices;
import com.wily.ui.selection.DateTimeSelector;

public class BaselineComparisonPicker extends JPanel
	{
	private static final long serialVersionUID = 1L;
	public JComboBox fAgentPicker;
	public JComboBox fDurationPicker;
	public DateTimeSelector fDateTimeSelector;
	public static String[] sDurations;
	//public HistoricalRangeTimeControl fControl;
	
	
	public BaselineComparisonPicker(IThornhillItem item, IGenericServices genericServices, 
			ClockManager clockManager,
			ThornhillUserInterface iface, 
			String title, 
			AgentName[] agentNames, 
			Date defaultDate)
		{
		initUI(item, genericServices, clockManager, iface, title, agentNames, defaultDate);
		}

	private void initUI(IThornhillItem item, IGenericServices genericServices, ClockManager clockManager, ThornhillUserInterface iface, String title, AgentName[] agentNames, Date defaultDate)
		{
		TitledBorder titledBorder = new TitledBorder(title);
		this.setBorder(titledBorder);
		this.setLayout(new BorderLayout());
		
		JPanel topPanel = new JPanel();
		FlowLayout flowLayout = new FlowLayout();
		flowLayout.setHgap(50);
		topPanel.setLayout(flowLayout);
		
		fAgentPicker = new JComboBox(agentNames);
		fAgentPicker.setEditable(false);
		fAgentPicker.setMaximumRowCount(20);
		
		fAgentPicker.setSelectedItem(getAgentNameFromThornhillItem(item));
		
		fAgentPicker.setPreferredSize(new Dimension(300, fAgentPicker.getPreferredSize().height));
		fAgentPicker.addActionListener(new ActionListener() {

			public void actionPerformed(ActionEvent arg0)
				{
				BaselineComparisonTypeViewer.sChannel.debug(BaselineComparisonTypeViewer.sModule, "agent picker size: " + getAgentPicker().getSize());
				}
			
		});
		
		topPanel.add(fAgentPicker);
		
		this.add(topPanel, BorderLayout.NORTH);
		
		JPanel bottomPanel = new JPanel();
		bottomPanel.setLayout(flowLayout);
		
		fDateTimeSelector = new DateTimeSelector(clockManager);
		fDateTimeSelector.setDate(defaultDate);
		bottomPanel.add(fDateTimeSelector);
		
		sDurations = new String[] {"8 Minutes", "20 Minutes", "1 Hour", "2 Hours", "6 Hours", "12 Hours", "24 Hours", "2 Days", "7 Days", "30 Days"};
		fDurationPicker = new JComboBox(sDurations);
		fDurationPicker.setEditable(false);
		fDurationPicker.setMaximumRowCount(sDurations.length);
		bottomPanel.add(fDurationPicker);
		
		
		//fControl = new HistoricalRangeTimeControl(genericServices, iface);
		//bottomPanel.add(fControl);
		this.add(bottomPanel, BorderLayout.SOUTH);
		}

	public static AgentName getAgentNameFromThornhillItem(IThornhillItem item)
		{
		AgentName result = null;
		
		if(item instanceof ThornhillAgent)
			{
			ThornhillAgent agent = (ThornhillAgent) item;
			result = agent.getAgentName();
			}
		else if (item instanceof ThornhillMetricPath)
			{
			ThornhillMetricPath metricPath = (ThornhillMetricPath) item;
			result = metricPath.getAgentName();
			}
		else if (item instanceof ThornhillMetric)
			{
			ThornhillMetric metric = (ThornhillMetric)item;
			result = metric.getMetric().getAgentName();
			}
		
		return result;
		}

	public JComboBox getAgentPicker()
		{
		return fAgentPicker;
		}
	
	public JComboBox getDurationPicker()
		{
		return fDurationPicker;
		}
	
	public DateTimeSelector getDateTimeSelector()
		{
		return fDateTimeSelector;
		}
	}
